@@ -374,11 +374,12 @@ class BERT(Transformer):
         if self.with_pool:
             # pooler 提取cls向量
             x = self.apply(x, layer=Lambda, name='Pooler', function=lambda x: x[:, 0])
+            pool_activation = 'tanh' if self.with_pool is True else self.with_pool
             x = self.apply(x,
                            layer=Dense,
                            name='Pooler-Dense',
                            units=self.hidden_size,
-                           activation='tanh',
+                           activation=pool_activation,
                            kernel_initializer=self.initializer)
             if self.with_nsp:
                 # Next sentence prediction
@@ -407,7 +408,8 @@ class BERT(Transformer):
             # 重用embedding-token layer
             x = self.apply(x, Embedding, 'Embedding-Token', arguments={'mode': 'dense'})
             x = self.apply(x, BiasAdd, 'MLM-Bias')
-            x = self.apply(x, Activation, 'MLM-Activation', activation='softmax')
+            mlm_activation = 'softmax' if self.with_mlm is True else self.with_mlm
+            x = self.apply(x, Activation, 'MLM-Activation', activation=mlm_activation)
             outputs.append(x)
 
         if len(outputs) == 1:
@@ -520,6 +522,19 @@ class NEZHA(BERT):
 
     ref: [NEZHA: Neural Contextualized Representation for Chinese Language Understanding](http://arxiv.org/abs/1909.00204)
     """
+
+    def __init__(self,
+                 external_embedding_size=None,
+                 external_embedding_weights=None,
+                 **kwargs):
+        """
+        增加引入外部embedding
+        """
+
+        super(NEZHA, self).__init__(**kwargs)
+        self.external_embedding_size = external_embedding_size  # 外部embedding 输出维度
+        self.external_embedding_weights = external_embedding_weights  # 外部embedding 初始化权重
+
     def apply_embeddings(self, inputs):
         """
         embedding 是 token embedding 与 segment embedding 的和
@@ -540,7 +555,26 @@ class NEZHA(BERT):
                                        output_dim=self.embedding_size,
                                        embeddings_initializer=self.initializer,
                                        )
-        x = self.apply([token_embedding, segment_embedding], Add, name='Embedding-Token-Segment')
+        token_with_segment = self.apply([token_embedding, segment_embedding], Add, name='Embedding-Token-Segment')
+
+        # add External knowledge
+        if self.external_embedding_size:
+            external_embedding = self.apply(x,
+                                            Embedding,
+                                            name='Embedding-External',
+                                            input_dim=self.vocab_size,
+                                            output_dim=self.external_embedding_size,
+                                            weights=[self.external_embedding_weights]
+                                            )
+            if self.external_embedding_size != self.embedding_size:
+                external_embedding = self.apply(external_embedding,
+                                                Dense,
+                                                name='External-Embedding-Mapping',
+                                                units=self.embedding_size,
+                                                kernel_initializer=self.initializer)
+            x = self.apply([token_with_segment, external_embedding], Add, name='Embedding-Token-Segment-External')
+        else:
+            x = token_with_segment
 
         x = self.apply(x,
                        LayerNormalization,
